package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallConfig;
import com.ruoyi.mall.service.IMallConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import javax.annotation.Resource;

/**
 * 商城相关设置Controller
 *
 * @author ruoyi
 * @date 2024-03-26
 */
@RestController
@RequestMapping("/mall/mallConfig")
public class MallConfigController extends BaseController
{
    @Resource
    private IMallConfigService mallConfigService;

    /**
     * 查询商城相关设置列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallConfig mallConfig)
    {
        startPage();
        mallConfig.setDelFlag(0);
        List<MallConfig> list = mallConfigService.selectMallConfigList(mallConfig);
        return getDataTable(list);
    }

    /**
     * 导出商城相关设置列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfig:export')")
    @Log(title = "商城相关设置", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallConfig mallConfig)
    {
        List<MallConfig> list = mallConfigService.selectMallConfigList(mallConfig);
        ExcelUtil<MallConfig> util = new ExcelUtil<MallConfig>(MallConfig.class);
        return util.exportExcel(list, "商城相关设置数据");
    }

    /**
     * 获取商城相关设置详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallConfigService.selectMallConfigById(id));
    }

    /**
     * 新增商城相关设置
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfig:add')")
    @Log(title = "商城相关设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallConfig mallConfig)
    {
        return toAjax(mallConfigService.insertMallConfig(mallConfig));
    }

    /**
     * 修改商城相关设置
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfig:edit')")
    @Log(title = "商城相关设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallConfig mallConfig)
    {
        return toAjax(mallConfigService.updateMallConfig(mallConfig));
    }

    /**
     * 删除商城相关设置
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfig:remove')")
    @Log(title = "商城相关设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallConfigService.deleteMallConfigByIds(ids));
    }
}
